/***************************************************************************
 *   Copyright (C) 2009 by Rick L. Vinyard, Jr.                            *
 *   rvinyard@cs.nmsu.edu                                                  *
 *                                                                         *
 *   This file is part of the papyrus library.                             *
 *                                                                         *
 *   papyrus is free software; you can redistribute it and/or modify       *
 *   it under the terms of the GNU Lesser General Public License           *
 *   version 3.0 as published by the Free Software Foundation.             *
 *                                                                         *
 *   papyrus is distributed in the hope that it will be useful,            *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU Lesser General Public License version 3.0 for more details.       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with the papyrus library. If not, see                   *
 *   <http://www.gnu.org/licenses/>.                                       *
 ***************************************************************************/
#ifndef PAPYRUSPAINT_H
#define PAPYRUSPAINT_H

#include <papyrus/renderable.h>

namespace Papyrus
{

//   typedef Cairo::RefPtr<Cairo::Pattern> Paint;

  /**
    @author Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
  */
  class Paint : public Renderable
  {
    protected:
      Paint ( const Glib::ustring& id, Cairo::RefPtr<Cairo::Pattern> pattern );

    public:
      typedef PapyrusPointer<Paint> pointer;

      static pointer create( );

      static pointer create( const Glib::ustring& color_string );

      static pointer create( Cairo::RefPtr<Cairo::Pattern> p );

      static pointer create( const Glib::ustring& id, const Glib::ustring& color_string );

      static pointer create( const Glib::ustring& id, Cairo::RefPtr<Cairo::Pattern> p );

      ~Paint();

      Paint& operator=( pointer other );

      Paint& operator=( Cairo::RefPtr<Cairo::Pattern> p );

      /** Sets to the current cairo pattern */
      Paint& operator=( Cairo::RefPtr<Cairo::Context> c );

      Paint& operator=( const Paint& other );

      void set( pointer other );

      void set( Cairo::RefPtr<Cairo::Pattern> p );

      /** Sets to the current cairo pattern */
      void set( Cairo::RefPtr<Cairo::Context> cairo );

      Cairo::RefPtr<Cairo::Pattern> cairo_pattern() const;

      operator Cairo::RefPtr<Cairo::Pattern>() const;

      virtual void render ( Cairo::RefPtr< Cairo :: Context > cairo ) const;

    protected:
      Cairo::RefPtr<Cairo::Pattern> m_pattern;

  };

  /**
   * A dictionary of paints
   */
  typedef std::map<Glib::ustring,Paint::pointer> PaintDictionary;

}

#endif
